@@ -196,7 +196,6 @@ BrowserWindow::BrowserWindow(Qz::BrowserWindowType type, const QUrl &startUrl)
     , m_startTab(0)
     , m_startPage(0)
     , m_sideBarManager(new SideBarManager(this))
-    , m_isHtmlFullScreen(false)
     , m_hideNavigationTimer(0)
 {
     setAttribute(Qt::WA_DeleteOnClose);
@@ -582,7 +581,7 @@ void BrowserWindow::loadSettings()
     //Browser Window settings
     settings.beginGroup("Browser-View-Settings");
     bool showStatusBar = settings.value("showStatusBar", false).toBool();
-    bool showBookmarksToolbar = settings.value("showBookmarksToolbar", true).toBool();
+    bool showBookmarksToolbar = settings.value("showBookmarksToolbar", false).toBool();
     bool showNavigationToolbar = settings.value("showNavigationToolbar", true).toBool();
     bool showMenuBar = settings.value("showMenubar", false).toBool();
 
@@ -610,15 +609,17 @@ void BrowserWindow::loadSettings()
     }
     settings.endGroup();
 
+    m_statusBarVisible = showStatusBar;
     statusBar()->setVisible(!isFullScreen() && showStatusBar);
     m_bookmarksToolbar->setVisible(showBookmarksToolbar);
     m_navigationToolbar->setVisible(showNavigationToolbar);
 
 #ifndef Q_OS_MACOS
+    m_menuBarVisible = showMenuBar;
     menuBar()->setVisible(!isFullScreen() && showMenuBar);
 #endif
 
-    m_navigationToolbar->setSuperMenuVisible(!showMenuBar);
+    m_navigationToolbar->setSuperMenuVisible(isFullScreen() || !showMenuBar);
 }
 
 void BrowserWindow::goForward()
@@ -809,8 +810,8 @@ void BrowserWindow::loadAddress(const QUrl &url)
         int index = m_tabWidget->addView(url, qzSettings->newTabPosition);
         weView(index)->setFocus();
     } else {
-        weView()->load(url);
         weView()->setFocus();
+        weView()->load(url);
     }
 }
 
@@ -925,7 +926,7 @@ void BrowserWindow::toggleTabsOnTop(bool enable)
 
 void BrowserWindow::toggleFullScreen()
 {
-    if (m_isHtmlFullScreen) {
+    if (m_htmlFullScreenView) {
         weView()->triggerPageAction(QWebEnginePage::ExitFullScreen);
         return;
     }
@@ -937,7 +938,7 @@ void BrowserWindow::toggleFullScreen()
     }
 }
 
-void BrowserWindow::toggleHtmlFullScreen(bool enable)
+void BrowserWindow::requestHtmlFullScreen(TabbedWebView *view, bool enable)
 {
     if (enable) {
         setWindowState(windowState() | Qt::WindowFullScreen);
@@ -948,7 +949,7 @@ void BrowserWindow::toggleHtmlFullScreen(bool enable)
     if (m_sideBar)
         m_sideBar.data()->setHidden(enable);
 
-    m_isHtmlFullScreen = enable;
+    m_htmlFullScreenView = enable ? view : nullptr;
 }
 
 void BrowserWindow::showWebInspector()
@@ -965,11 +966,6 @@ void BrowserWindow::toggleWebInspector()
     }
 }
 
-void BrowserWindow::refreshHistory()
-{
-    m_navigationToolbar->refreshHistory();
-}
-
 void BrowserWindow::currentTabChanged()
 {
     TabbedWebView* view = weView();
@@ -1181,7 +1177,7 @@ bool BrowserWindow::fullScreenNavigationVisible() const
 
 void BrowserWindow::showNavigationWithFullScreen()
 {
-    if (m_isHtmlFullScreen)
+    if (m_htmlFullScreenView)
         return;
 
     if (m_hideNavigationTimer->isActive()) {
@@ -1226,6 +1222,9 @@ bool BrowserWindow::event(QEvent *event)
 
             m_navigationContainer->hide();
             m_navigationToolbar->enterFullScreen();
+
+            // Show main menu button since menubar is hidden
+            m_navigationToolbar->setSuperMenuVisible(true);
         }
         else if (e->oldState() & Qt::WindowFullScreen && !(windowState() & Qt::WindowFullScreen)) {
             // Leave fullscreen
@@ -1237,7 +1236,7 @@ bool BrowserWindow::event(QEvent *event)
             m_navigationContainer->show();
             m_navigationToolbar->setSuperMenuVisible(!m_menuBarVisible);
             m_navigationToolbar->leaveFullScreen();
-            m_isHtmlFullScreen = false;
+            m_htmlFullScreenView = nullptr;
         }
 
         if (m_hideNavigationTimer) {
