@@ -123,7 +123,6 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     // Set fallback icon theme (eg. on Windows/Mac)
     if (QIcon::fromTheme(QSL("view-refresh")).isNull()) {
-        QIcon::setThemeSearchPaths(QStringList() << QL1S(":/breeze-fallback"));
         QIcon::setThemeName(QSL("breeze-fallback"));
     }
 
@@ -206,6 +205,11 @@ MainApplication::MainApplication(int &argc, char** argv)
         }
     }
 
+    if (!isPortable()) {
+        QSettings falkonConf(QSL("%1/falkon.conf").arg(applicationDirPath()), QSettings::IniFormat);
+        m_isPortable = falkonConf.value(QSL("Config/Portable")).toBool();
+    }
+
     if (isPortable()) {
         std::cout << "Falkon: Running in Portable Mode." << std::endl;
         DataPaths::setPortableVersion();
@@ -783,7 +787,7 @@ void MainApplication::saveSettings()
         m_cookieJar->deleteAllCookies();
     }
     if (deleteCache) {
-        QzTools::removeDir(mApp->webProfile()->cachePath());
+        QzTools::removeRecursively(mApp->webProfile()->cachePath());
     }
 
     m_searchEnginesManager->saveSettings();
@@ -1067,26 +1071,29 @@ void MainApplication::setupUserScripts()
     script.setInjectionPoint(QWebEngineScript::DocumentCreation);
     script.setWorldId(WebPage::SafeJsWorld);
     script.setRunsOnSubFrames(true);
-    script.setSourceCode(Scripts::setupWebChannel(script.worldId()));
+    script.setSourceCode(Scripts::setupWebChannel());
     m_webProfile->scripts()->insert(script);
 
-    // WebChannel for UnsafeJsWorld
-    QWebEngineScript script2;
-    script2.setName(QSL("_falkon_webchannel2"));
-    script2.setInjectionPoint(QWebEngineScript::DocumentCreation);
-    script2.setWorldId(WebPage::UnsafeJsWorld);
-    script2.setRunsOnSubFrames(true);
-    script2.setSourceCode(Scripts::setupWebChannel(script2.worldId()));
-    m_webProfile->scripts()->insert(script2);
+    // falkon:restore
+    QWebEngineScript falkonRestore;
+    falkonRestore.setWorldId(WebPage::SafeJsWorld);
+    falkonRestore.setSourceCode(QzTools::readAllFileContents(QSL(":html/restore.user.js")));
+    m_webProfile->scripts()->insert(falkonRestore);
+
+    // falkon:speeddial
+    QWebEngineScript falkonSpeedDial;
+    falkonSpeedDial.setWorldId(WebPage::SafeJsWorld);
+    falkonSpeedDial.setSourceCode(Scripts::setupSpeedDial());
+    m_webProfile->scripts()->insert(falkonSpeedDial);
 
     // document.window object addons
-    QWebEngineScript script3;
-    script3.setName(QSL("_falkon_window_object"));
-    script3.setInjectionPoint(QWebEngineScript::DocumentCreation);
-    script3.setWorldId(WebPage::UnsafeJsWorld);
-    script3.setRunsOnSubFrames(true);
-    script3.setSourceCode(Scripts::setupWindowObject());
-    m_webProfile->scripts()->insert(script3);
+    QWebEngineScript documentWindowAddons;
+    documentWindowAddons.setName(QSL("_falkon_window_object"));
+    documentWindowAddons.setInjectionPoint(QWebEngineScript::DocumentCreation);
+    documentWindowAddons.setWorldId(WebPage::UnsafeJsWorld);
+    documentWindowAddons.setRunsOnSubFrames(true);
+    documentWindowAddons.setSourceCode(Scripts::setupWindowObject());
+    m_webProfile->scripts()->insert(documentWindowAddons);
 }
 
 void MainApplication::setUserStyleSheet(const QString &filePath)
@@ -1163,14 +1170,15 @@ void MainApplication::initPulseSupport()
 RegisterQAppAssociation* MainApplication::associationManager()
 {
     if (!m_registerQAppAssociation) {
-        QString desc = tr("Falkon is a new, fast and secure open-source WWW browser. Falkon is licensed under GPL version 3 or (at your option) any later version. It is based on WebKit core and Qt Framework.");
+        QString desc = tr("Falkon is a new and very fast Qt web browser. Falkon is licensed under GPL version 3 or (at your option) any later version. It is based on QtWebEngine and Qt Framework.");
         QString fileIconPath = QApplication::applicationFilePath() + ",1";
         QString appIconPath = QApplication::applicationFilePath() + ",0";
         m_registerQAppAssociation = new RegisterQAppAssociation("Falkon", QApplication::applicationFilePath(), appIconPath, desc, this);
-        m_registerQAppAssociation->addCapability(".html", "Falkon.HTML", "HTML File", fileIconPath, RegisterQAppAssociation::FileAssociation);
-        m_registerQAppAssociation->addCapability(".htm", "Falkon.HTM", "HTM File", fileIconPath, RegisterQAppAssociation::FileAssociation);
-        m_registerQAppAssociation->addCapability("http", "Falkon.HTTP", "URL:HyperText Transfer Protocol", appIconPath, RegisterQAppAssociation::UrlAssociation);
-        m_registerQAppAssociation->addCapability("https", "Falkon.HTTPS", "URL:HyperText Transfer Protocol with Privacy", appIconPath, RegisterQAppAssociation::UrlAssociation);
+        m_registerQAppAssociation->addCapability(".html", "FalkonHTML", "Falkon HTML Document", fileIconPath, RegisterQAppAssociation::FileAssociation);
+        m_registerQAppAssociation->addCapability(".htm", "FalkonHTML", "Falkon HTML Document", fileIconPath, RegisterQAppAssociation::FileAssociation);
+        m_registerQAppAssociation->addCapability("http", "FalkonURL", "Falkon URL", appIconPath, RegisterQAppAssociation::UrlAssociation);
+        m_registerQAppAssociation->addCapability("https", "FalkonURL", "Falkon URL", appIconPath, RegisterQAppAssociation::UrlAssociation);
+        m_registerQAppAssociation->addCapability("ftp", "FalkonURL", "Falkon URL", appIconPath, RegisterQAppAssociation::UrlAssociation);
     }
     return m_registerQAppAssociation;
 }
