@@ -28,6 +28,8 @@
 #include <QSqlDatabase>
 #include <QMessageBox>
 #include <QSettings>
+#include <QStandardPaths>
+
 #include <iostream>
 
 ProfileManager::ProfileManager()
@@ -38,7 +40,11 @@ void ProfileManager::initConfigDir()
 {
     QDir dir(DataPaths::path(DataPaths::Config));
 
-    if (dir.exists() && QFile(dir.filePath(QLatin1String("profiles/profiles.ini"))).exists()) {
+    if (!dir.exists()) {
+        migrateFromQupZilla();
+    }
+
+    if (QFileInfo::exists(dir.filePath(QLatin1String("profiles/profiles.ini")))) {
         return;
     }
 
@@ -115,7 +121,7 @@ bool ProfileManager::removeProfile(const QString &profileName)
         return false;
     }
 
-    QzTools::removeDir(dir.absolutePath());
+    QzTools::removeRecursively(dir.absolutePath());
     return true;
 }
 
@@ -183,8 +189,12 @@ void ProfileManager::updateProfile(const QString &current, const QString &profil
 
     Updater::Version prof(profile);
 
+    // Profile is from newer version than running application
     if (prof > Updater::Version(Qz::VERSION)) {
-        copyDataToProfile();
+        // Only copy data when profile is not from development version
+        if (prof.revisionNumber != 99) {
+            copyDataToProfile();
+        }
         return;
     }
 
@@ -198,7 +208,10 @@ void ProfileManager::updateProfile(const QString &current, const QString &profil
         return;
     }
 
-    // Nothing for now
+    // No change in 3.0
+    if (prof < Updater::Version("3.0.99")) {
+        return;
+    }
 }
 
 void ProfileManager::copyDataToProfile()
@@ -236,6 +249,29 @@ void ProfileManager::copyDataToProfile()
     }
 }
 
+void ProfileManager::migrateFromQupZilla()
+{
+    if (mApp->isPortable()) {
+        return;
+    }
+
+#if defined(Q_OS_WIN)
+    const QString qzConfig = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QL1S("/qupzilla");
+#elif defined(Q_OS_MACOS)
+    const QString qzConfig = QDir::homePath() + QLatin1String("/Library/Application Support/QupZilla");
+#else // Unix
+    const QString qzConfig = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QL1S("/qupzilla");
+#endif
+
+    if (!QFileInfo::exists(qzConfig)) {
+        return;
+    }
+
+    std::cout << "Falkon: Migrating config from QupZilla..." << std::endl;
+
+    QzTools::copyRecursively(qzConfig, DataPaths::path(DataPaths::Config));
+}
+
 void ProfileManager::connectDatabase()
 {
     QSqlDatabase db = QSqlDatabase::addDatabase(QLatin1String("QSQLITE"));
