@@ -187,7 +187,7 @@ void LocationBar::showDomainCompletion(const QString &completion)
 
     // We need to manually force the completion because model is updated asynchronously
     // But only force completion when the user actually added new text
-    if (m_oldTextLength < m_currentTextLength)
+    if (!completion.isEmpty() && m_oldTextLength < m_currentTextLength)
         completer()->complete();
 }
 
@@ -277,12 +277,12 @@ LocationBar::LoadAction LocationBar::loadAction(const QString &text)
     }
 
     // Otherwise load as url
-    const QUrl &guessedUrl = QUrl::fromUserInput(t);
+    const QUrl guessedUrl = QUrl::fromUserInput(t);
     if (guessedUrl.isValid()) {
         // Always allow javascript: to be loaded
         const bool forceLoad = guessedUrl.scheme() == QL1S("javascript");
         // Only allow spaces in query
-        if (forceLoad || !QzTools::containsSpace(guessedUrl.toString(QUrl::RemoveQuery))) {
+        if (forceLoad || !QzTools::containsSpace(t) || !QzTools::containsSpace(guessedUrl.toString(QUrl::RemoveQuery))) {
             // Only allow whitelisted schemes
             static const QSet<QString> whitelistedSchemes = {
                 QSL("http"), QSL("https"), QSL("ftp"), QSL("file"),
@@ -345,6 +345,7 @@ void LocationBar::refreshTextFormat()
 void LocationBar::requestLoadUrl()
 {
     loadRequest(loadAction(text()).loadRequest);
+    updateSiteIcon();
 }
 
 void LocationBar::textEdited(const QString &text)
@@ -630,7 +631,6 @@ void LocationBar::loadStarted()
     m_progressVisible = true;
     m_progressTimer->stop();
     m_autofillIcon->hide();
-    m_siteIcon->setIcon(IconProvider::emptyWebIcon());
 }
 
 void LocationBar::loadProgress(int progress)
