@@ -141,15 +141,22 @@ Preferences::Preferences(BrowserWindow* window)
     ui->dontLoadTabsUntilSelected->setChecked(settings.value("Web-Browser-Settings/LoadTabsOnActivation", true).toBool());
 
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
-    ui->checkDefaultBrowser->setChecked(settings.value("Web-Browser-Settings/CheckDefaultBrowser", DEFAULT_CHECK_DEFAULTBROWSER).toBool());
-    if (mApp->associationManager()->isDefaultForAllCapabilities()) {
-        ui->checkNowDefaultBrowser->setText(tr("Default"));
-        ui->checkNowDefaultBrowser->setEnabled(false);
+    if (!mApp->isPortable()) {
+        ui->checkDefaultBrowser->setChecked(settings.value("Web-Browser-Settings/CheckDefaultBrowser",
+                                                           DEFAULT_CHECK_DEFAULTBROWSER).toBool());
+        if (mApp->associationManager()->isDefaultForAllCapabilities()) {
+            ui->checkNowDefaultBrowser->setText(tr("Default"));
+            ui->checkNowDefaultBrowser->setEnabled(false);
+        }
+        else {
+            ui->checkNowDefaultBrowser->setText(tr("Set as default"));
+            ui->checkNowDefaultBrowser->setEnabled(true);
+            connect(ui->checkNowDefaultBrowser, SIGNAL(clicked()), this, SLOT(makeFalkonDefault()));
+        }
     }
     else {
-        ui->checkNowDefaultBrowser->setText(tr("Set as default"));
-        ui->checkNowDefaultBrowser->setEnabled(true);
-        connect(ui->checkNowDefaultBrowser, SIGNAL(clicked()), this, SLOT(makeFalkonDefault()));
+        ui->checkDefaultBrowser->hide();
+        ui->checkNowDefaultBrowser->hide();
     }
 #else // No Default Browser settings on non-Windows platform
     ui->hSpacerDefaultBrowser->changeSize(0, 0, QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -207,8 +214,8 @@ Preferences::Preferences(BrowserWindow* window)
     ui->showStatusbar->setChecked(settings.value("showStatusBar", false).toBool());
     // NOTE: instantBookmarksToolbar and showBookmarksToolbar cannot be both enabled at the same time
     ui->instantBookmarksToolbar->setChecked(settings.value("instantBookmarksToolbar", false).toBool());
-    ui->showBookmarksToolbar->setChecked(settings.value("showBookmarksToolbar", true).toBool());
-    ui->instantBookmarksToolbar->setDisabled(settings.value("showBookmarksToolbar", true).toBool());
+    ui->showBookmarksToolbar->setChecked(settings.value("showBookmarksToolbar", false).toBool());
+    ui->instantBookmarksToolbar->setDisabled(settings.value("showBookmarksToolbar", false).toBool());
     ui->showBookmarksToolbar->setDisabled(settings.value("instantBookmarksToolbar").toBool());
     connect(ui->instantBookmarksToolbar, SIGNAL(toggled(bool)), ui->showBookmarksToolbar, SLOT(setDisabled(bool)));
     connect(ui->showBookmarksToolbar, SIGNAL(toggled(bool)), ui->instantBookmarksToolbar, SLOT(setDisabled(bool)));
@@ -435,6 +442,8 @@ Preferences::Preferences(BrowserWindow* window)
             QListWidgetItem *item = new QListWidgetItem;
             item->setText(langName);
             item->setData(Qt::UserRole, lang);
+            item->setFlags(item->flags() & ~Qt::ItemIsSelectable);
+            item->setCheckState(Qt::Unchecked);
             ui->spellcheckLanguages->addItem(item);
         }
     }
@@ -448,7 +457,7 @@ Preferences::Preferences(BrowserWindow* window)
         QListWidgetItem *item = items.at(0);
         ui->spellcheckLanguages->takeItem(ui->spellcheckLanguages->row(item));
         ui->spellcheckLanguages->insertItem(topIndex++, item);
-        ui->spellcheckLanguages->setCurrentItem(item, QItemSelectionModel::Select);
+        item->setCheckState(Qt::Checked);
     }
 
     if (ui->spellcheckLanguages->count() == 0) {
@@ -961,7 +970,7 @@ void Preferences::saveSettings()
     QStringList languages;
     for (int i = 0; i < ui->spellcheckLanguages->count(); ++i) {
         QListWidgetItem *item = ui->spellcheckLanguages->item(i);
-        if (item->isSelected()) {
+        if (item->checkState() == Qt::Checked) {
             languages.append(item->data(Qt::UserRole).toString());
         }
     }
