@@ -93,7 +93,6 @@ TabWidget::TabWidget(BrowserWindow *window, QWidget *parent)
     m_tabBar = new TabBar(m_window, this);
     setTabBar(m_tabBar);
 
-    connect(this, SIGNAL(currentChanged(int)), m_window, SLOT(refreshHistory()));
     connect(this, &TabWidget::changed, mApp, &MainApplication::changeOccurred);
     connect(this, &TabStackedWidget::pinStateChanged, this, &TabWidget::changed);
 
@@ -777,6 +776,7 @@ void TabWidget::restoreClosedTab(QObject* obj)
 
     int index = addView(QUrl(), tab.tabState.title, Qz::NT_CleanSelectedTab, false, tab.position);
     WebTab* webTab = weTab(index);
+    webTab->setParentTab(tab.parentTab);
     webTab->p_restoreTab(tab.tabState);
 
     updateClosedTabsButton();
@@ -792,6 +792,7 @@ void TabWidget::restoreAllClosedTabs()
     for (const ClosedTabsManager::Tab &tab : closedTabs) {
         int index = addView(QUrl(), tab.tabState.title, Qz::NT_CleanSelectedTab);
         WebTab* webTab = weTab(index);
+        webTab->setParentTab(tab.parentTab);
         webTab->p_restoreTab(tab.tabState);
     }
 
