@@ -76,22 +76,6 @@ WebView::WebView(QWidget* parent)
     }
 
     WebInspector::registerView(this);
-
-    // Hack to find widget that receives input events
-    QStackedLayout *l = qobject_cast<QStackedLayout*>(layout());
-    connect(l, &QStackedLayout::currentChanged, this, [this]() {
-        QTimer::singleShot(0, this, [this]() {
-            m_rwhvqt = focusProxy();
-            if (!m_rwhvqt) {
-                qCritical() << "Focus proxy is null!";
-                return;
-            }
-            m_rwhvqt->installEventFilter(this);
-            if (QQuickWidget *w = qobject_cast<QQuickWidget*>(m_rwhvqt)) {
-                w->setClearColor(palette().color(QPalette::Window));
-            }
-        });
-    });
 }
 
 WebView::~WebView()
@@ -469,13 +453,6 @@ void WebView::slotUrlChanged(const QUrl &url)
         emit titleChanged(title());
         m_backgroundActivity = oldActivity;
     }
-
-    // Don't save blank page / speed dial in tab history
-    if (!history()->canGoForward()  && history()->backItems(1).size() == 1) {
-        const QString s = LocationBar::convertUrlToText(history()->backItem().url());
-        if (s.isEmpty())
-            history()->clear();
-    }
 }
 
 void WebView::slotTitleChanged(const QString &title)
@@ -518,7 +495,21 @@ void WebView::copyLinkToClipboard()
 
 void WebView::savePageAs()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    page()->runJavaScript(QSL("document.contentType"), WebPage::SafeJsWorld, [this](const QVariant &res) {
+        const QSet<QString> webPageTypes = {
+            QSL("text/html"),
+            QSL("application/xhtml+xml")
+        };
+        if (res.isNull() || webPageTypes.contains(res.toString())) {
+            triggerPageAction(QWebEnginePage::SavePage);
+        } else {
+            page()->download(url());
+        }
+    });
+#else
     triggerPageAction(QWebEnginePage::SavePage);
+#endif
 }
 
 void WebView::copyImageToClipboard()
@@ -837,11 +828,13 @@ void WebView::createLinkContextMenu(QMenu* menu, const WebHitTestResult &hitTest
 void WebView::createImageContextMenu(QMenu* menu, const WebHitTestResult &hitTest)
 {
     menu->addSeparator();
-    Action* act = new Action(tr("Show i&mage"));
-    act->setData(hitTest.imageUrl());
-    connect(act, SIGNAL(triggered()), this, SLOT(openActionUrl()));
-    connect(act, SIGNAL(ctrlTriggered()), this, SLOT(userDefinedOpenUrlInNewTab()));
-    menu->addAction(act);
+    if (hitTest.imageUrl() != url()) {
+        Action *act = new Action(tr("Show i&mage"));
+        act->setData(hitTest.imageUrl());
+        connect(act, SIGNAL(triggered()), this, SLOT(openActionUrl()));
+        connect(act, SIGNAL(ctrlTriggered()), this, SLOT(userDefinedOpenUrlInNewTab()));
+        menu->addAction(act);
+    }
     menu->addAction(tr("Copy image"), this, SLOT(copyImageToClipboard()));
     menu->addAction(QIcon::fromTheme("edit-copy"), tr("Copy image ad&dress"), this, SLOT(copyLinkToClipboard()))->setData(hitTest.imageUrl());
     menu->addSeparator();
@@ -1275,6 +1268,17 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
     });
 }
 
+bool WebView::focusNextPrevChild(bool next)
+{
+    // QTBUG-67043
+    // Workaround QtWebEngine issue where QWebEngineView loses focus on second load() call.
+    if (next) {
+        setFocus();
+        return false;
+    }
+    return QWebEngineView::focusNextPrevChild(next);
+}
+
 void WebView::loadRequest(const LoadRequest &req)
 {
     QWebEngineView::load(req.webRequest());
@@ -1287,6 +1291,19 @@ bool WebView::eventFilter(QObject *obj, QEvent *event)
         parentWidget()->installEventFilter(this);
     }
 
+    // Hack to find widget that receives input events
+    if (obj == this && event->type() == QEvent::ChildAdded) {
+        QTimer::singleShot(0, this, [this]() {
+            if (focusProxy() && m_rwhvqt != focusProxy()) {
+                m_rwhvqt = focusProxy();
+                m_rwhvqt->installEventFilter(this);
+                if (QQuickWidget *w = qobject_cast<QQuickWidget*>(m_rwhvqt)) {
+                    w->setClearColor(palette().color(QPalette::Window));
+                }
+            }
+        });
+    }
+
     // Forward events to WebView
 #define HANDLE_EVENT(f, t) \
     { \
